const type = {};
const types = 'Array Object String Date RegExp Function Boolean Number Error Null Undefined'.split(' ');
/**
 * Check the type of a value.
 */
type.is = (type, val) => Object.prototype.toString.call(val).slice(8, -1) === type;
// Populate helper methods.
types.forEach(t => (type[`is${t}`] = (v) => type.is(t, v)));

/**
 * Return the value or execute as a function
 */
function value(val, ...args) {
    return type.isFunction(val) ? val.apply(this, args) : val;
}

/**
 * Round a number to a given number of decimal places.
 */
function round(val, places = 2) {
    return Number(val.toFixed(places));
}

/**
 * Get the ordinal value for a given number.
 */
function ordinal(num) {
    const suffix = ['th', 'st', 'nd', 'rd'];
    let v = num % 100;
    return num + (suffix[(v - 20) % 10] || suffix[v] || suffix[0]);
}

export { type, value, round, ordinal };
//# sourceMappingURL=chitu.es.js.map
